@@ -23,11 +23,26 @@ class CalendarModel : public Akonadi::EntityTreeModel
     Q_OBJECT
 public:
     using Ptr = QSharedPointer<CalendarModel>;
-    enum ItemColumn { Summary = 0, Type, DateTimeStart, DateTimeEnd, DateTimeDue, Priority, PercentComplete, ItemColumnCount };
+    enum ItemColumn {
+        Summary = 0,
+        Type,
+        DateTimeStart,
+        DateTimeEnd,
+        DateTimeDue,
+        Priority,
+        PercentComplete,
+        ItemColumnCount
+    };
 
-    enum CollectionColumn { CollectionTitle = 0, CollectionColumnCount };
+    enum CollectionColumn {
+        CollectionTitle = 0,
+        CollectionColumnCount
+    };
 
-    enum Role { SortRole = Akonadi::EntityTreeModel::UserRole, RecursRole };
+    enum Role {
+        SortRole = Akonadi::EntityTreeModel::UserRole,
+        RecursRole
+    };
 
     static Akonadi::CalendarModel::Ptr create(Akonadi::Monitor *monitor);
     ~CalendarModel() override;
